@@ -7,8 +7,8 @@ my $markdown;
 eval "use Text::MultiMarkdown";
 unless ($@) {
     $markdown = Text::MultiMarkdown->new(
-        markdown_in_html_blocks => 1,
-        use_metadata => 0,
+        markdown_in_html_blocks => 1, # Allow Markdown syntax within HTML blocks.
+        use_metadata => 0, # Remove MultiMarkdown behavior change to make the top of the document metadata.
         heading_ids  => 0, # Remove MultiMarkdown behavior change in <hX> tags.
         img_ids      => 0, # Remove MultiMarkdown behavior change in <img> tags.
     );
@@ -49,7 +49,7 @@ sub format_content {
     my ($class,$content,$c)=@_;
     return unless $markdown;
     return unless $c->pref('main_formatter') eq 'MojoMojo::Formatter::Markdown';
-    # Let textile handle the rest
+    # Let markdown handle the rest
     $$content= $markdown->markdown( $$content );
 }
 
@@ -57,7 +57,7 @@ sub format_content {
 
 =head1 SEE ALSO
 
-L<MojoMojo>,L<Module::Pluggable::Ordered>,L<Text::Markdown>
+L<MojoMojo>,L<Module::Pluggable::Ordered>,L<Text::MultiMarkdown>
 
 =head1 AUTHORS
 
